<p align="center">
    <a href="https://github.com/cyanbook/deezepy">
        <img src="https://i.imgur.com/TQz2qbu.jpg" alt="Deezepy">
    </a>
    <br>
    <b>Elegant Python wrapper for Deezer API</b>
    <br>
    <a href="">
        Documentation
    </a>
    •
    <a href="">
        Releases
    </a>
    •
    <a href="">
        Support
    </a>
</p>

---

## Deezepy
``` python
>>> import deezepy
>>> client = deezepy.Client()
>>> client.get_track(760429392).title
'Come Together'
```
**Deezepy** is an elegant, intuitive and easy-to-use Python wrapper for Deezer API.

### Installation

```pip install deezepy```

### Requirements
- Python 3.6 or higher

### License
Deezepy is licensed under GNU GPLv3